@@ -1,7 +1,7 @@
 from .utils import map_person_publications, map_node, map_edge_all_publications
 
 
-def drop_old_publications(summary, year):
+def drop_old_person_publications(summary, year):
     def callback(_, publication):
         if publication["year"] >= year:
             return publication
@@ -9,7 +9,7 @@ def drop_old_publications(summary, year):
     return map_person_publications(summary, callback)
 
 
-def drop_nodes_by_publications(summary, n):
+def drop_nodes_by_all_publications(summary, n):
     def callback(_, node):
         if len(node["person"]["publications"]) >= n:
             return node
@@ -17,7 +17,7 @@ def drop_nodes_by_publications(summary, n):
     return map_node(summary, callback)
 
 
-def drop_nodes_by_all_publications(summary, n):
+def drop_edges_by_all_publications(summary, n):
     def callback(edge, publications):
         if len(publications) >= n:
             return edge
